/* game-window.c generated by valac 0.34.0, the Vala compiler
 * generated from game-window.vala, do not modify */

/* -*- Mode: vala; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * Copyright (C) 2015-2016 Arnaud Bonatti <arnaud.bonatti@gmail.com>
 *
 * This file is part of a GNOME game.
 *
 * This application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this application. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>


#define TYPE_GAME_WINDOW_FLAGS (game_window_flags_get_type ())

#define TYPE_GAME_WINDOW (game_window_get_type ())
#define GAME_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GAME_WINDOW, GameWindow))
#define GAME_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GAME_WINDOW, GameWindowClass))
#define IS_GAME_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GAME_WINDOW))
#define IS_GAME_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GAME_WINDOW))
#define GAME_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GAME_WINDOW, GameWindowClass))

typedef struct _GameWindow GameWindow;
typedef struct _GameWindowClass GameWindowClass;
typedef struct _GameWindowPrivate GameWindowPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

typedef enum  {
	GAME_WINDOW_FLAGS_SHOW_UNDO = 1 << 0,
	GAME_WINDOW_FLAGS_SHOW_REDO = 1 << 1,
	GAME_WINDOW_FLAGS_SHOW_HINT = 1 << 2,
	GAME_WINDOW_FLAGS_SHOW_START_BUTTON = 1 << 3
} GameWindowFlags;

struct _GameWindow {
	GtkApplicationWindow parent_instance;
	GameWindowPrivate * priv;
	GSimpleAction* undo_action;
	GSimpleAction* redo_action;
};

struct _GameWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _GameWindowPrivate {
	gboolean tiled_state;
	gboolean maximized_state;
	gint window_width;
	gint window_height;
	gboolean game_finished;
	GtkHeaderBar* headerbar;
	GtkStack* stack;
	GtkButton* start_game_button;
	GtkButton* new_game_button;
	GtkButton* back_button;
	GtkBox* controls_box;
	GtkBox* game_box;
	GtkBox* new_game_box;
	GtkBox* side_box;
	GtkWidget* view;
	GSimpleAction* back_action;
};


static gpointer game_window_parent_class = NULL;

GType game_window_flags_get_type (void) G_GNUC_CONST;
GType game_window_get_type (void) G_GNUC_CONST;
#define GAME_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GAME_WINDOW, GameWindowPrivate))
enum  {
	GAME_WINDOW_DUMMY_PROPERTY
};
static void game_window_new_game_cb (GameWindow* self);
static void _game_window_new_game_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void game_window_start_game_cb (GameWindow* self);
static void _game_window_start_game_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void game_window_back_cb (GameWindow* self);
static void _game_window_back_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void game_window_undo_cb (GameWindow* self);
static void _game_window_undo_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void game_window_redo_cb (GameWindow* self);
static void _game_window_redo_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void game_window_hint_cb (GameWindow* self);
static void _game_window_hint_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
GameWindow* game_window_new (const gchar* css_resource, const gchar* name, gint width, gint height, gboolean maximized, gboolean start_now, GameWindowFlags flags, GtkBox* new_game_screen, GtkWidget* _view);
GameWindow* game_window_construct (GType object_type, const gchar* css_resource, const gchar* name, gint width, gint height, gboolean maximized, gboolean start_now, GameWindowFlags flags, GtkBox* new_game_screen, GtkWidget* _view);
static void game_window_size_allocate_cb (GameWindow* self);
static void _game_window_size_allocate_cb_gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self);
static gboolean game_window_window_state_event_cb (GameWindow* self, GdkEventWindowState* event);
static gboolean _game_window_window_state_event_cb_gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self);
static void game_window_show_view (GameWindow* self);
static void game_window_show_new_game_screen (GameWindow* self);
void game_window_shutdown (GameWindow* self, GSettings* settings);
void game_window_add_to_sidebox (GameWindow* self, GtkWidget* widget);
void game_window_cannot_undo_more (GameWindow* self);
void game_window_set_subtitle (GameWindow* self, const gchar* subtitle);
void game_window_finish_game (GameWindow* self);
static void game_window_finalize (GObject* obj);

static const GActionEntry GAME_WINDOW_win_actions[6] = {{"new-game", _game_window_new_game_cb_gsimple_action_activate_callback}, {"start-game", _game_window_start_game_cb_gsimple_action_activate_callback}, {"back", _game_window_back_cb_gsimple_action_activate_callback}, {"undo", _game_window_undo_cb_gsimple_action_activate_callback}, {"redo", _game_window_redo_cb_gsimple_action_activate_callback}, {"hint", _game_window_hint_cb_gsimple_action_activate_callback}};

GType game_window_flags_get_type (void) {
	static volatile gsize game_window_flags_type_id__volatile = 0;
	if (g_once_init_enter (&game_window_flags_type_id__volatile)) {
		static const GFlagsValue values[] = {{GAME_WINDOW_FLAGS_SHOW_UNDO, "GAME_WINDOW_FLAGS_SHOW_UNDO", "show-undo"}, {GAME_WINDOW_FLAGS_SHOW_REDO, "GAME_WINDOW_FLAGS_SHOW_REDO", "show-redo"}, {GAME_WINDOW_FLAGS_SHOW_HINT, "GAME_WINDOW_FLAGS_SHOW_HINT", "show-hint"}, {GAME_WINDOW_FLAGS_SHOW_START_BUTTON, "GAME_WINDOW_FLAGS_SHOW_START_BUTTON", "show-start-button"}, {0, NULL, NULL}};
		GType game_window_flags_type_id;
		game_window_flags_type_id = g_flags_register_static ("GameWindowFlags", values);
		g_once_init_leave (&game_window_flags_type_id__volatile, game_window_flags_type_id);
	}
	return game_window_flags_type_id__volatile;
}


static void _game_window_new_game_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 75 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_new_game_cb ((GameWindow*) self);
#line 139 "game-window.c"
}


static void _game_window_start_game_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 75 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_start_game_cb ((GameWindow*) self);
#line 146 "game-window.c"
}


static void _game_window_back_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 75 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_back_cb ((GameWindow*) self);
#line 153 "game-window.c"
}


static void _game_window_undo_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 75 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_undo_cb ((GameWindow*) self);
#line 160 "game-window.c"
}


static void _game_window_redo_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 75 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_redo_cb ((GameWindow*) self);
#line 167 "game-window.c"
}


static void _game_window_hint_cb_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 75 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_hint_cb ((GameWindow*) self);
#line 174 "game-window.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 100 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	return self ? g_object_ref (self) : NULL;
#line 181 "game-window.c"
}


static void _game_window_size_allocate_cb_gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self) {
#line 121 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_size_allocate_cb ((GameWindow*) self);
#line 188 "game-window.c"
}


static gboolean _game_window_window_state_event_cb_gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self) {
	gboolean result;
	result = game_window_window_state_event_cb ((GameWindow*) self, event);
#line 122 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	return result;
#line 197 "game-window.c"
}


GameWindow* game_window_construct (GType object_type, const gchar* css_resource, const gchar* name, gint width, gint height, gboolean maximized, gboolean start_now, GameWindowFlags flags, GtkBox* new_game_screen, GtkWidget* _view) {
	GameWindow * self = NULL;
	const gchar* _tmp0_ = NULL;
	GtkWidget* _tmp6_ = NULL;
	GtkWidget* _tmp7_ = NULL;
	GAction* _tmp8_ = NULL;
	GSimpleAction* _tmp9_ = NULL;
	GAction* _tmp10_ = NULL;
	GSimpleAction* _tmp11_ = NULL;
	GAction* _tmp12_ = NULL;
	GSimpleAction* _tmp13_ = NULL;
	GSimpleAction* _tmp14_ = NULL;
	GSimpleAction* _tmp15_ = NULL;
	GSimpleAction* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	GtkHeaderBar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	gint _tmp20_ = 0;
	gint _tmp21_ = 0;
	gboolean _tmp22_ = FALSE;
	GtkBox* _tmp23_ = NULL;
	GtkBox* _tmp24_ = NULL;
	GameWindowFlags _tmp25_ = 0;
	GtkBox* _tmp37_ = NULL;
	GtkWidget* _tmp38_ = NULL;
	GtkBox* _tmp39_ = NULL;
	GtkWidget* _tmp40_ = NULL;
	GtkWidget* _tmp41_ = NULL;
	GtkWidget* _tmp42_ = NULL;
	GtkWidget* _tmp43_ = NULL;
	GameWindowFlags _tmp44_ = 0;
	gboolean _tmp59_ = FALSE;
#line 91 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 91 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_val_if_fail (new_game_screen != NULL, NULL);
#line 91 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_val_if_fail (_view != NULL, NULL);
#line 91 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self = (GameWindow*) g_object_new (object_type, NULL);
#line 93 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = css_resource;
#line 93 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp0_ != NULL) {
#line 245 "game-window.c"
		GtkCssProvider* css_provider = NULL;
		GtkCssProvider* _tmp1_ = NULL;
		GtkCssProvider* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		GdkScreen* _tmp4_ = NULL;
		GtkCssProvider* _tmp5_ = NULL;
#line 95 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp1_ = gtk_css_provider_new ();
#line 95 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		css_provider = _tmp1_;
#line 96 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp2_ = css_provider;
#line 96 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp3_ = css_resource;
#line 96 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_css_provider_load_from_resource (_tmp2_, _tmp3_);
#line 97 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp4_ = gdk_screen_get_default ();
#line 97 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp5_ = css_provider;
#line 97 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_style_context_add_provider_for_screen (_tmp4_, (GtkStyleProvider*) _tmp5_, (guint) GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
#line 93 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_g_object_unref0 (css_provider);
#line 270 "game-window.c"
	}
#line 100 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp6_ = _view;
#line 100 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 100 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->view);
#line 100 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->view = _tmp7_;
#line 103 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_action_map_add_action_entries ((GActionMap*) self, GAME_WINDOW_win_actions, G_N_ELEMENTS (GAME_WINDOW_win_actions), self);
#line 105 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp8_ = g_action_map_lookup_action ((GActionMap*) self, "back");
#line 105 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, g_simple_action_get_type (), GSimpleAction));
#line 105 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->back_action);
#line 105 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->back_action = _tmp9_;
#line 106 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp10_ = g_action_map_lookup_action ((GActionMap*) self, "undo");
#line 106 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, g_simple_action_get_type (), GSimpleAction));
#line 106 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->undo_action);
#line 106 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->undo_action = _tmp11_;
#line 107 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp12_ = g_action_map_lookup_action ((GActionMap*) self, "redo");
#line 107 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, g_simple_action_get_type (), GSimpleAction));
#line 107 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->redo_action);
#line 107 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->redo_action = _tmp13_;
#line 109 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp14_ = self->priv->back_action;
#line 109 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp14_, FALSE);
#line 110 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp15_ = self->undo_action;
#line 110 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp15_, FALSE);
#line 111 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp16_ = self->redo_action;
#line 111 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp16_, FALSE);
#line 114 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp17_ = name;
#line 114 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_window_set_title ((GtkWindow*) self, _tmp17_);
#line 115 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp18_ = self->priv->headerbar;
#line 115 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp19_ = name;
#line 115 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_header_bar_set_title (_tmp18_, _tmp19_);
#line 117 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp20_ = width;
#line 117 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp21_ = height;
#line 117 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_window_set_default_size ((GtkWindow*) self, _tmp20_, _tmp21_);
#line 118 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp22_ = maximized;
#line 118 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp22_) {
#line 119 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_window_maximize ((GtkWindow*) self);
#line 340 "game-window.c"
	}
#line 121 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_connect_object ((GtkWidget*) self, "size-allocate", (GCallback) _game_window_size_allocate_cb_gtk_widget_size_allocate, self, 0);
#line 122 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_connect_object ((GtkWidget*) self, "window-state-event", (GCallback) _game_window_window_state_event_cb_gtk_widget_window_state_event, self, 0);
#line 125 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp23_ = self->priv->new_game_box;
#line 125 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp24_ = new_game_screen;
#line 125 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_box_pack_start (_tmp23_, (GtkWidget*) _tmp24_, TRUE, TRUE, (guint) 0);
#line 126 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp25_ = flags;
#line 126 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if ((_tmp25_ & GAME_WINDOW_FLAGS_SHOW_START_BUTTON) == GAME_WINDOW_FLAGS_SHOW_START_BUTTON) {
#line 356 "game-window.c"
		const gchar* _tmp26_ = NULL;
		GtkButton* _tmp27_ = NULL;
		GtkButton* _tmp28_ = NULL;
		GtkButton* _tmp29_ = NULL;
		GtkButton* _tmp30_ = NULL;
		GtkButton* _tmp31_ = NULL;
		GtkButton* _tmp32_ = NULL;
		GtkStyleContext* _tmp33_ = NULL;
		GtkButton* _tmp34_ = NULL;
		GtkBox* _tmp35_ = NULL;
		GtkButton* _tmp36_ = NULL;
#line 128 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp26_ = _ ("_Start Game");
#line 128 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp27_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp26_);
#line 128 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		g_object_ref_sink (_tmp27_);
#line 128 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_g_object_unref0 (self->priv->start_game_button);
#line 128 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		self->priv->start_game_button = _tmp27_;
#line 130 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp28_ = self->priv->start_game_button;
#line 130 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		g_object_set ((GtkWidget*) _tmp28_, "width-request", 222, NULL);
#line 131 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp29_ = self->priv->start_game_button;
#line 131 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		g_object_set ((GtkWidget*) _tmp29_, "height-request", 60, NULL);
#line 132 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp30_ = self->priv->start_game_button;
#line 132 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_set_halign ((GtkWidget*) _tmp30_, GTK_ALIGN_CENTER);
#line 133 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp31_ = self->priv->start_game_button;
#line 133 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_actionable_set_action_name ((GtkActionable*) _tmp31_, "win.start-game");
#line 134 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp32_ = self->priv->start_game_button;
#line 134 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp33_ = gtk_widget_get_style_context ((GtkWidget*) _tmp32_);
#line 134 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_style_context_add_class (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_style_context_get_type (), GtkStyleContext), "suggested-action");
#line 135 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp34_ = self->priv->start_game_button;
#line 135 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_show ((GtkWidget*) _tmp34_);
#line 136 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp35_ = self->priv->new_game_box;
#line 136 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp36_ = self->priv->start_game_button;
#line 136 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_box_pack_end (_tmp35_, (GtkWidget*) _tmp36_, FALSE, FALSE, (guint) 0);
#line 410 "game-window.c"
	}
#line 139 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp37_ = self->priv->game_box;
#line 139 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp38_ = self->priv->view;
#line 139 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_box_pack_start (_tmp37_, _tmp38_, TRUE, TRUE, (guint) 0);
#line 140 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp39_ = self->priv->game_box;
#line 140 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp40_ = self->priv->view;
#line 140 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_container_set_focus_child ((GtkContainer*) _tmp39_, _tmp40_);
#line 141 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp41_ = self->priv->view;
#line 141 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_set_halign (_tmp41_, GTK_ALIGN_FILL);
#line 142 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp42_ = self->priv->view;
#line 142 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_object_set (_tmp42_, "can-focus", TRUE, NULL);
#line 143 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp43_ = self->priv->view;
#line 143 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_show (_tmp43_);
#line 146 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp44_ = flags;
#line 146 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if ((_tmp44_ & GAME_WINDOW_FLAGS_SHOW_UNDO) == GAME_WINDOW_FLAGS_SHOW_UNDO) {
#line 440 "game-window.c"
		GtkBox* history_box = NULL;
		GtkBox* _tmp45_ = NULL;
		GtkBox* _tmp46_ = NULL;
		GtkStyleContext* _tmp47_ = NULL;
		GtkButton* undo_button = NULL;
		GtkButton* _tmp48_ = NULL;
		GtkButton* _tmp49_ = NULL;
		GtkButton* _tmp50_ = NULL;
		const gchar* _tmp51_ = NULL;
		GtkButton* _tmp52_ = NULL;
		GtkButton* _tmp53_ = NULL;
		GtkBox* _tmp54_ = NULL;
		GtkButton* _tmp55_ = NULL;
		GtkBox* _tmp56_ = NULL;
		GtkBox* _tmp57_ = NULL;
		GtkBox* _tmp58_ = NULL;
#line 148 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp45_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 148 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		g_object_ref_sink (_tmp45_);
#line 148 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		history_box = _tmp45_;
#line 149 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp46_ = history_box;
#line 149 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp47_ = gtk_widget_get_style_context ((GtkWidget*) _tmp46_);
#line 149 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_style_context_add_class (_tmp47_, "linked");
#line 151 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp48_ = (GtkButton*) gtk_button_new_from_icon_name ("edit-undo-symbolic", GTK_ICON_SIZE_BUTTON);
#line 151 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		g_object_ref_sink (_tmp48_);
#line 151 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		undo_button = _tmp48_;
#line 152 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp49_ = undo_button;
#line 152 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_actionable_set_action_name ((GtkActionable*) _tmp49_, "win.undo");
#line 153 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp50_ = undo_button;
#line 153 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp51_ = _ ("Undo your most recent move");
#line 153 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp50_, _tmp51_);
#line 154 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp52_ = undo_button;
#line 154 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_set_valign ((GtkWidget*) _tmp52_, GTK_ALIGN_CENTER);
#line 155 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp53_ = undo_button;
#line 155 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_show ((GtkWidget*) _tmp53_);
#line 156 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp54_ = history_box;
#line 156 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp55_ = undo_button;
#line 156 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_box_pack_start (_tmp54_, (GtkWidget*) _tmp55_, TRUE, TRUE, (guint) 0);
#line 168 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp56_ = history_box;
#line 168 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_show ((GtkWidget*) _tmp56_);
#line 169 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp57_ = self->priv->controls_box;
#line 169 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp58_ = history_box;
#line 169 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_box_pack_start (_tmp57_, (GtkWidget*) _tmp58_, TRUE, TRUE, (guint) 0);
#line 146 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_g_object_unref0 (undo_button);
#line 146 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_g_object_unref0 (history_box);
#line 513 "game-window.c"
	}
#line 182 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp59_ = start_now;
#line 182 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp59_) {
#line 183 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		game_window_show_view (self);
#line 521 "game-window.c"
	} else {
#line 185 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		game_window_show_new_game_screen (self);
#line 525 "game-window.c"
	}
#line 91 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	return self;
#line 529 "game-window.c"
}


GameWindow* game_window_new (const gchar* css_resource, const gchar* name, gint width, gint height, gboolean maximized, gboolean start_now, GameWindowFlags flags, GtkBox* new_game_screen, GtkWidget* _view) {
#line 91 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	return game_window_construct (TYPE_GAME_WINDOW, css_resource, name, width, height, maximized, start_now, flags, new_game_screen, _view);
#line 536 "game-window.c"
}


static void game_window_size_allocate_cb (GameWindow* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 192 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 194 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = self->priv->maximized_state;
#line 194 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp1_) {
#line 194 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp0_ = TRUE;
#line 553 "game-window.c"
	} else {
		gboolean _tmp2_ = FALSE;
#line 194 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp2_ = self->priv->tiled_state;
#line 194 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp0_ = _tmp2_;
#line 560 "game-window.c"
	}
#line 194 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp0_) {
#line 195 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		return;
#line 566 "game-window.c"
	}
#line 196 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_window_get_size ((GtkWindow*) self, &_tmp3_, &_tmp4_);
#line 196 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->window_width = _tmp3_;
#line 196 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->window_height = _tmp4_;
#line 574 "game-window.c"
}


static gboolean game_window_window_state_event_cb (GameWindow* self, GdkEventWindowState* event) {
	gboolean result = FALSE;
	GdkEventWindowState* _tmp0_ = NULL;
	GdkWindowState _tmp1_ = 0;
	GdkEventWindowState* _tmp4_ = NULL;
	GdkWindowState _tmp5_ = 0;
#line 199 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 199 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 201 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = event;
#line 201 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = _tmp0_->changed_mask;
#line 201 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if ((_tmp1_ & GDK_WINDOW_STATE_MAXIMIZED) != 0) {
#line 594 "game-window.c"
		GdkEventWindowState* _tmp2_ = NULL;
		GdkWindowState _tmp3_ = 0;
#line 202 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp2_ = event;
#line 202 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp3_ = _tmp2_->new_window_state;
#line 202 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		self->priv->maximized_state = (_tmp3_ & GDK_WINDOW_STATE_MAXIMIZED) != 0;
#line 603 "game-window.c"
	}
#line 204 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp4_ = event;
#line 204 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp5_ = _tmp4_->changed_mask;
#line 204 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if ((_tmp5_ & GDK_WINDOW_STATE_TILED) != 0) {
#line 611 "game-window.c"
		GdkEventWindowState* _tmp6_ = NULL;
		GdkWindowState _tmp7_ = 0;
#line 205 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp6_ = event;
#line 205 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp7_ = _tmp6_->new_window_state;
#line 205 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		self->priv->tiled_state = (_tmp7_ & GDK_WINDOW_STATE_TILED) != 0;
#line 620 "game-window.c"
	}
#line 206 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	result = FALSE;
#line 206 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	return result;
#line 626 "game-window.c"
}


void game_window_shutdown (GameWindow* self, GSettings* settings) {
	GSettings* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	GSettings* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	GSettings* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 209 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 209 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (settings != NULL);
#line 211 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = settings;
#line 211 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = self->priv->window_width;
#line 211 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_settings_set_int (_tmp0_, "window-width", _tmp1_);
#line 212 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp2_ = settings;
#line 212 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp3_ = self->priv->window_height;
#line 212 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_settings_set_int (_tmp2_, "window-height", _tmp3_);
#line 213 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp4_ = settings;
#line 213 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp5_ = self->priv->maximized_state;
#line 213 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_settings_set_boolean (_tmp4_, "window-is-maximized", _tmp5_);
#line 214 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_destroy ((GtkWidget*) self);
#line 661 "game-window.c"
}


void game_window_add_to_sidebox (GameWindow* self, GtkWidget* widget) {
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 221 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 221 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (widget != NULL);
#line 223 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->side_box;
#line 223 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = widget;
#line 223 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_box_pack_start (_tmp0_, _tmp1_, FALSE, FALSE, (guint) 0);
#line 678 "game-window.c"
}


void game_window_cannot_undo_more (GameWindow* self) {
	GSimpleAction* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 226 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 228 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->undo_action;
#line 228 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp0_, FALSE);
#line 229 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = self->priv->view;
#line 229 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_grab_focus (_tmp1_);
#line 695 "game-window.c"
}


void game_window_set_subtitle (GameWindow* self, const gchar* subtitle) {
	GtkHeaderBar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 232 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 234 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->headerbar;
#line 234 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = subtitle;
#line 234 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_header_bar_set_subtitle (_tmp0_, _tmp1_);
#line 710 "game-window.c"
}


void game_window_finish_game (GameWindow* self) {
	GtkButton* _tmp0_ = NULL;
#line 237 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 239 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->game_finished = TRUE;
#line 240 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->new_game_button;
#line 240 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp0_);
#line 724 "game-window.c"
}


static void game_window_show_new_game_screen (GameWindow* self) {
	GtkHeaderBar* _tmp0_ = NULL;
	GtkStack* _tmp1_ = NULL;
	GtkBox* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
#line 252 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 254 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->headerbar;
#line 254 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_header_bar_set_subtitle (_tmp0_, NULL);
#line 256 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = self->priv->stack;
#line 256 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_stack_set_visible_child_name (_tmp1_, "start-box");
#line 257 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp2_ = self->priv->controls_box;
#line 257 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_hide ((GtkWidget*) _tmp2_);
#line 259 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp4_ = self->priv->game_finished;
#line 259 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (!_tmp4_) {
#line 752 "game-window.c"
		GtkButton* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
#line 259 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp5_ = self->priv->back_button;
#line 259 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp6_ = gtk_widget_get_visible ((GtkWidget*) _tmp5_);
#line 259 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp7_ = _tmp6_;
#line 259 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp3_ = _tmp7_;
#line 764 "game-window.c"
	} else {
#line 259 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp3_ = FALSE;
#line 768 "game-window.c"
	}
#line 259 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp3_) {
#line 772 "game-window.c"
		GtkButton* _tmp8_ = NULL;
#line 260 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp8_ = self->priv->back_button;
#line 260 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 778 "game-window.c"
	} else {
		GtkButton* _tmp9_ = NULL;
#line 261 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp9_ = self->priv->start_game_button;
#line 261 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		if (_tmp9_ != NULL) {
#line 785 "game-window.c"
			GtkButton* _tmp10_ = NULL;
#line 262 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
			_tmp10_ = self->priv->start_game_button;
#line 262 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp10_);
#line 791 "game-window.c"
		}
	}
}


static void game_window_show_view (GameWindow* self) {
	GtkStack* _tmp0_ = NULL;
	GtkButton* _tmp1_ = NULL;
	GtkBox* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 265 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 267 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->stack;
#line 267 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_stack_set_visible_child_name (_tmp0_, "frame");
#line 268 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = self->priv->back_button;
#line 268 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_hide ((GtkWidget*) _tmp1_);
#line 269 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp2_ = self->priv->controls_box;
#line 269 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_show ((GtkWidget*) _tmp2_);
#line 271 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp3_ = self->priv->game_finished;
#line 271 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp3_) {
#line 820 "game-window.c"
		GtkButton* _tmp4_ = NULL;
#line 272 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp4_ = self->priv->new_game_button;
#line 272 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_grab_focus ((GtkWidget*) _tmp4_);
#line 826 "game-window.c"
	} else {
		GtkWidget* _tmp5_ = NULL;
#line 274 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp5_ = self->priv->view;
#line 274 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_grab_focus (_tmp5_);
#line 833 "game-window.c"
	}
}


static void game_window_new_game_cb (GameWindow* self) {
	GtkStack* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkStack* _tmp2_ = NULL;
	GtkStack* _tmp3_ = NULL;
	GtkButton* _tmp4_ = NULL;
	GSimpleAction* _tmp5_ = NULL;
#line 281 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 283 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->stack;
#line 283 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = gtk_stack_get_visible_child_name (_tmp0_);
#line 283 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (g_strcmp0 (_tmp1_, "frame") != 0) {
#line 284 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		return;
#line 855 "game-window.c"
	}
#line 286 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_emit_by_name (self, "wait");
#line 288 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp2_ = self->priv->stack;
#line 288 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_stack_set_transition_type (_tmp2_, GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT);
#line 289 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp3_ = self->priv->stack;
#line 289 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_stack_set_transition_duration (_tmp3_, (guint) 800);
#line 291 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp4_ = self->priv->back_button;
#line 291 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_show ((GtkWidget*) _tmp4_);
#line 292 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp5_ = self->priv->back_action;
#line 292 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp5_, TRUE);
#line 294 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_show_new_game_screen (self);
#line 877 "game-window.c"
}


static void game_window_start_game_cb (GameWindow* self) {
	GtkStack* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GSimpleAction* _tmp2_ = NULL;
	GSimpleAction* _tmp3_ = NULL;
	GtkStack* _tmp4_ = NULL;
	GtkStack* _tmp5_ = NULL;
#line 297 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 299 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->stack;
#line 299 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = gtk_stack_get_visible_child_name (_tmp0_);
#line 299 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (g_strcmp0 (_tmp1_, "start-box") != 0) {
#line 300 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		return;
#line 898 "game-window.c"
	}
#line 302 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->game_finished = FALSE;
#line 304 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp2_ = self->undo_action;
#line 304 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp2_, FALSE);
#line 305 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp3_ = self->redo_action;
#line 305 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp3_, FALSE);
#line 307 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_emit_by_name (self, "play");
#line 309 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp4_ = self->priv->stack;
#line 309 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_stack_set_transition_type (_tmp4_, GTK_STACK_TRANSITION_TYPE_SLIDE_DOWN);
#line 310 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp5_ = self->priv->stack;
#line 310 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_stack_set_transition_duration (_tmp5_, (guint) 1000);
#line 311 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_show_view (self);
#line 922 "game-window.c"
}


static void game_window_back_cb (GameWindow* self) {
	GtkStack* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkStack* _tmp2_ = NULL;
	GtkStack* _tmp3_ = NULL;
#line 314 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 316 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->stack;
#line 316 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = gtk_stack_get_visible_child_name (_tmp0_);
#line 316 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (g_strcmp0 (_tmp1_, "start-box") != 0) {
#line 317 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		return;
#line 941 "game-window.c"
	}
#line 319 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp2_ = self->priv->stack;
#line 319 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_stack_set_transition_type (_tmp2_, GTK_STACK_TRANSITION_TYPE_SLIDE_RIGHT);
#line 320 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp3_ = self->priv->stack;
#line 320 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_stack_set_transition_duration (_tmp3_, (guint) 800);
#line 321 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_show_view (self);
#line 323 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_emit_by_name (self, "back");
#line 955 "game-window.c"
}


static void game_window_undo_cb (GameWindow* self) {
	GtkStack* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkButton* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	GSimpleAction* _tmp6_ = NULL;
#line 330 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 332 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->stack;
#line 332 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = gtk_stack_get_visible_child_name (_tmp0_);
#line 332 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (g_strcmp0 (_tmp1_, "frame") != 0) {
#line 333 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		return;
#line 976 "game-window.c"
	}
#line 335 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->game_finished = FALSE;
#line 337 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp2_ = self->priv->new_game_button;
#line 337 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_object_get ((GtkWidget*) _tmp2_, "is-focus", &_tmp3_, NULL);
#line 337 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp4_ = _tmp3_;
#line 337 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp4_) {
#line 988 "game-window.c"
		GtkWidget* _tmp5_ = NULL;
#line 338 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp5_ = self->priv->view;
#line 338 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_grab_focus (_tmp5_);
#line 994 "game-window.c"
	}
#line 339 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp6_ = self->redo_action;
#line 339 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp6_, TRUE);
#line 340 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_emit_by_name (self, "undo");
#line 1002 "game-window.c"
}


static void game_window_redo_cb (GameWindow* self) {
	GtkStack* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkButton* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	GSimpleAction* _tmp6_ = NULL;
#line 343 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 345 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->stack;
#line 345 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = gtk_stack_get_visible_child_name (_tmp0_);
#line 345 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (g_strcmp0 (_tmp1_, "frame") != 0) {
#line 346 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		return;
#line 1023 "game-window.c"
	}
#line 348 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp2_ = self->priv->new_game_button;
#line 348 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_object_get ((GtkWidget*) _tmp2_, "is-focus", &_tmp3_, NULL);
#line 348 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp4_ = _tmp3_;
#line 348 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (_tmp4_) {
#line 1033 "game-window.c"
		GtkWidget* _tmp5_ = NULL;
#line 349 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		_tmp5_ = self->priv->view;
#line 349 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		gtk_widget_grab_focus (_tmp5_);
#line 1039 "game-window.c"
	}
#line 350 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp6_ = self->undo_action;
#line 350 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_simple_action_set_enabled (_tmp6_, TRUE);
#line 351 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_emit_by_name (self, "redo");
#line 1047 "game-window.c"
}


static void game_window_hint_cb (GameWindow* self) {
	GtkStack* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 354 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_return_if_fail (self != NULL);
#line 356 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp0_ = self->priv->stack;
#line 356 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_tmp1_ = gtk_stack_get_visible_child_name (_tmp0_);
#line 356 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	if (g_strcmp0 (_tmp1_, "frame") != 0) {
#line 357 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
		return;
#line 1064 "game-window.c"
	}
#line 358 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_emit_by_name (self, "hint");
#line 1068 "game-window.c"
}


static void game_window_class_init (GameWindowClass * klass) {
	gint GameWindow_private_offset;
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	game_window_parent_class = g_type_class_peek_parent (klass);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_type_class_add_private (klass, sizeof (GameWindowPrivate));
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	G_OBJECT_CLASS (klass)->finalize = game_window_finalize;
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	GameWindow_private_offset = g_type_class_get_instance_private_offset (klass);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/taquin/ui/game-window.ui");
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_new ("play", TYPE_GAME_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_new ("wait", TYPE_GAME_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_new ("back", TYPE_GAME_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_new ("undo", TYPE_GAME_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_new ("redo", TYPE_GAME_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	g_signal_new ("hint", TYPE_GAME_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "headerbar", FALSE, GameWindow_private_offset + G_STRUCT_OFFSET (GameWindowPrivate, headerbar));
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "stack", FALSE, GameWindow_private_offset + G_STRUCT_OFFSET (GameWindowPrivate, stack));
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "new_game_button", FALSE, GameWindow_private_offset + G_STRUCT_OFFSET (GameWindowPrivate, new_game_button));
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_button", FALSE, GameWindow_private_offset + G_STRUCT_OFFSET (GameWindowPrivate, back_button));
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "controls_box", FALSE, GameWindow_private_offset + G_STRUCT_OFFSET (GameWindowPrivate, controls_box));
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "game_box", FALSE, GameWindow_private_offset + G_STRUCT_OFFSET (GameWindowPrivate, game_box));
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "new_game_box", FALSE, GameWindow_private_offset + G_STRUCT_OFFSET (GameWindowPrivate, new_game_box));
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "side_box", FALSE, GameWindow_private_offset + G_STRUCT_OFFSET (GameWindowPrivate, side_box));
#line 1112 "game-window.c"
}


static void game_window_instance_init (GameWindow * self) {
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv = GAME_WINDOW_GET_PRIVATE (self);
#line 40 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->game_finished = FALSE;
#line 48 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self->priv->start_game_button = NULL;
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1125 "game-window.c"
}


static void game_window_finalize (GObject* obj) {
	GameWindow * self;
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GAME_WINDOW, GameWindow);
#line 44 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->headerbar);
#line 46 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->stack);
#line 48 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->start_game_button);
#line 50 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->new_game_button);
#line 52 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->back_button);
#line 55 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->controls_box);
#line 57 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->game_box);
#line 59 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->new_game_box);
#line 61 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->side_box);
#line 63 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->view);
#line 86 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->priv->back_action);
#line 88 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->undo_action);
#line 89 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	_g_object_unref0 (self->redo_action);
#line 32 "/mnt/test/jhbuild/jhbuild/gnome-taquin/src/game-window.vala"
	G_OBJECT_CLASS (game_window_parent_class)->finalize (obj);
#line 1161 "game-window.c"
}


GType game_window_get_type (void) {
	static volatile gsize game_window_type_id__volatile = 0;
	if (g_once_init_enter (&game_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GameWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) game_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GameWindow), 0, (GInstanceInitFunc) game_window_instance_init, NULL };
		GType game_window_type_id;
		game_window_type_id = g_type_register_static (gtk_application_window_get_type (), "GameWindow", &g_define_type_info, 0);
		g_once_init_leave (&game_window_type_id__volatile, game_window_type_id);
	}
	return game_window_type_id__volatile;
}



